@@ -3,10 +3,10 @@ import torch.optim as optim
 import torch.nn as nn
 
 from lpd.trainer import Trainer
-from lpd.callbacks import SchedulerStep, StatsPrint, ModelCheckPoint, LossOptimizerHandler
+from lpd.callbacks import SchedulerStep, StatsPrint, ModelCheckPoint, LossOptimizerHandler, CallbackMonitor
 from lpd.extensions.custom_schedulers import DoNothingToLR
 from lpd.enums import Phase, State, MonitorType, StatsType, MonitorMode
-from lpd.metrics import BinaryAccuracyWithLogits
+from lpd.metrics import BinaryAccuracyWithLogits, MetricBase
 import lpd.utils.torch_utils as tu
 import lpd.utils.general_utils as gu
 import examples.utils as eu
@@ -26,6 +26,17 @@ def get_parameters():
     data_loader_steps = 100
     return N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps
 
+
+# LET'S CREATE A CUSTOM (ALTOUGH NOT SO INFORMATIVE) METRIC
+class InaccuracyWithLogits(MetricBase):
+    def __init__(self):
+        self.bawl = BinaryAccuracyWithLogits() # we exploit BinaryAccuracyWithLogits for the computation
+
+    def __call__(self, y_pred, y_true): # <=== implement this method!
+        acc = self.bawl(y_pred, y_true)
+        return 1 - acc  # return the inaccuracy
+
+
 def get_trainer_base(D_in, H, D_out):
     device = tu.get_gpu_device_if_available()
 
@@ -37,8 +48,7 @@ def get_trainer_base(D_in, H, D_out):
 
     scheduler = DoNothingToLR() #CAN ALSO USE scheduler=None, BUT DoNothingToLR IS MORE EXPLICIT
     
-    # LETS ADD 2 METRICS (EVEN IF THEY ARE THE SAME) TO SEE StatsPrint WITH MULTIPLE METRICS
-    metric_name_to_func = {"acc1":BinaryAccuracyWithLogits(), "acc2":BinaryAccuracyWithLogits()}
+    metric_name_to_func = {"Accuracy":BinaryAccuracyWithLogits(), "InAccuracy":InaccuracyWithLogits()}
 
     return device, model, loss_func, optimizer, scheduler, metric_name_to_func
 
@@ -50,7 +60,18 @@ def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
                     #ADDING ModelCheckPoint WITH save_full_trainer=True TO SAVE FULL TRAINER
                     ModelCheckPoint(checkpoint_dir=save_to_dir, checkpoint_file_name=trainer_file_name, save_best_only=True, save_full_trainer=True),
                     SchedulerStep(),
-                    StatsPrint(metric_names=metric_name_to_func.keys())
+                    # SINCE ACCURACY NEEDS TO GO UP AND INACCURACY NEEDS TO GO DOWN, LETS DEFINE CallbackMonitors for StatsPrint PER EACH METRIC
+                    StatsPrint(train_metrics_monitors=[CallbackMonitor(patience=None, 
+                                                                    monitor_type=MonitorType.METRIC,
+                                                                    stats_type=StatsType.TRAIN,
+                                                                    monitor_mode=MonitorMode.MAX,
+                                                                    metric_name='Accuracy'),
+                                                    CallbackMonitor(patience=None, 
+                                                                    monitor_type=MonitorType.METRIC,
+                                                                    stats_type=StatsType.TRAIN,
+                                                                    monitor_mode=MonitorMode.MIN,
+                                                                    metric_name='InAccuracy')],
+                    )
                 ]
 
     trainer = Trainer(model=model, 
@@ -63,7 +84,6 @@ def get_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
                       val_data_loader=data_loader,
                       train_steps=data_loader_steps,
                       val_steps=data_loader_steps,
-                      num_epochs=num_epochs,
                       callbacks=callbacks,
                       name='Save-And-Load-Example')
     return trainer
@@ -87,12 +107,13 @@ def load_trainer(N, D_in, H, D_out, num_epochs, data_loader, data_loader_steps):
 
 def run():
     params = get_parameters()
+    num_epochs = params[4]
     current_trainer = get_trainer(*params)
 
     current_trainer.summary()
 
     # TRAINING WILL SAVE current_trainer IN ModelCheckPoint
-    current_trainer.train()
+    current_trainer.train(num_epochs)
 
     # YOU CAN ALSO SAVE THIS TRAINER MANUALLY, LIKE THE CODE BELOW
     current_trainer.save_trainer(save_to_dir, trainer_file_name + '_manual_save')
@@ -101,6 +122,6 @@ def run():
     loaded_trainer = load_trainer(*params)
 
     # CONTINUE TRAINING
-    loaded_trainer.train()
+    loaded_trainer.train(num_epochs)
 
     print('DONE')
\ No newline at end of file
